/*! firebase-admin v9.100.0-alpha.0 */
/*!
 * @license
 * Copyright 2017 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { app } from '../firebase-namespace-api';
import { Credential } from './credential';
/**
 * Type representing a callback which is called every time an app lifecycle event occurs.
 */
export declare type AppHook = (event: string, app: app.App) => void;
/**
 * Type representing a Firebase OAuth access token (derived from a Google OAuth2 access token) which
 * can be used to authenticate to Firebase services such as the Realtime Database and Auth.
 */
export interface FirebaseAccessToken {
    accessToken: string;
    expirationTime: number;
}
/**
 * Internals of a FirebaseApp instance.
 */
export declare class FirebaseAppInternals {
    private credential_;
    private isDeleted_;
    private cachedToken_;
    private cachedTokenPromise_;
    private tokenListeners_;
    private tokenRefreshTimeout_;
    constructor(credential_: Credential);
    /**
     * Gets an auth token for the associated app.
     *
     * @param {boolean} forceRefresh Whether or not to force a token refresh.
     * @return {Promise<FirebaseAccessToken>} A Promise that will be fulfilled with the current or
     *   new token.
     */
    getToken(forceRefresh?: boolean): Promise<FirebaseAccessToken>;
    /**
     * Adds a listener that is called each time a token changes.
     *
     * @param {function(string)} listener The listener that will be called with each new token.
     */
    addAuthTokenListener(listener: (token: string) => void): void;
    /**
     * Removes a token listener.
     *
     * @param {function(string)} listener The listener to remove.
     */
    removeAuthTokenListener(listener: (token: string) => void): void;
    /**
     * Deletes the FirebaseAppInternals instance.
     */
    delete(): void;
    /**
     * Establishes timeout to refresh the Google OAuth2 access token used by the SDK.
     *
     * @param {number} delayInMilliseconds The delay to use for the timeout.
     * @param {number} numRetries The number of times to retry fetching a new token if the prior fetch
     *   failed.
     */
    private setTokenRefreshTimeout;
}
