/*! firebase-admin v9.100.0-alpha.0 */
/*!
 * Copyright 2021 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { App } from '../app/index';
import { ActionCodeSettings as TActionCodeSettings } from './action-code-settings-builder';
import { Auth as TAuth } from './auth';
import { AuthFactorType as TAuthFactorType, AuthProviderConfig as TAuthProviderConfig, AuthProviderConfigFilter as TAuthProviderConfigFilter, CreateRequest as TCreateRequest, CreateMultiFactorInfoRequest as TCreateMultiFactorInfoRequest, CreatePhoneMultiFactorInfoRequest as TCreatePhoneMultiFactorInfoRequest, EmailSignInProviderConfig as TEmailSignInProviderConfig, ListProviderConfigResults as TListProviderConfigResults, MultiFactorCreateSettings as TMultiFactorCreateSettings, MultiFactorConfig as TMultiFactorConfig, MultiFactorConfigState as TMultiFactorConfigState, MultiFactorUpdateSettings as TMultiFactorUpdateSettings, OIDCAuthProviderConfig as TOIDCAuthProviderConfig, OIDCUpdateAuthProviderRequest as TOIDCUpdateAuthProviderRequest, SAMLAuthProviderConfig as TSAMLAuthProviderConfig, SAMLUpdateAuthProviderRequest as TSAMLUpdateAuthProviderRequest, UpdateAuthProviderRequest as TUpdateAuthProviderRequest, UpdateMultiFactorInfoRequest as TUpdateMultiFactorInfoRequest, UpdatePhoneMultiFactorInfoRequest as TUpdatePhoneMultiFactorInfoRequest, UpdateRequest as TUpdateRequest } from './auth-config';
import { BaseAuth as TBaseAuth, DeleteUsersResult as TDeleteUsersResult, GetUsersResult as TGetUsersResult, ListUsersResult as TListUsersResult, SessionCookieOptions as TSessionCookieOptions } from './base-auth';
import { EmailIdentifier as TEmailIdentifier, PhoneIdentifier as TPhoneIdentifier, ProviderIdentifier as TProviderIdentifier, UserIdentifier as TUserIdentifier, UidIdentifier as TUidIdentifier } from './identifier';
import { CreateTenantRequest as TCreateTenantRequest, Tenant as TTenant, UpdateTenantRequest as TUpdateTenantRequest } from './tenant';
import { ListTenantsResult as TListTenantsResult, TenantAwareAuth as TTenantAwareAuth, TenantManager as TTenantManager } from './tenant-manager';
import { DecodedIdToken as TDecodedIdToken } from './token-verifier';
import { HashAlgorithmType as THashAlgorithmType, UserImportOptions as TUserImportOptions, UserImportRecord as TUserImportRecord, UserImportResult as TUserImportResult, UserMetadataRequest as TUserMetadataRequest, UserProviderRequest as TUserProviderRequest } from './user-import-builder';
import { MultiFactorInfo as TMultiFactorInfo, MultiFactorSettings as TMultiFactorSettings, PhoneMultiFactorInfo as TPhoneMultiFactorInfo, UserInfo as TUserInfo, UserMetadata as TUserMetadata, UserRecord as TUserRecord } from './user-record';
/**
 * Gets the {@link auth.Auth `Auth`} service for the default app or a
 * given app.
 *
 * `admin.auth()` can be called with no arguments to access the default app's
 * {@link auth.Auth `Auth`} service or as `admin.auth(app)` to access the
 * {@link auth.Auth `Auth`} service associated with a specific app.
 *
 * @example
 * ```javascript
 * // Get the Auth service for the default app
 * var defaultAuth = admin.auth();
 * ```
 *
 * @example
 * ```javascript
 * // Get the Auth service for a given app
 * var otherAuth = admin.auth(otherApp);
 * ```
 *
 */
export declare function auth(app?: App): auth.Auth;
export declare namespace auth {
    type ActionCodeSettings = TActionCodeSettings;
    type Auth = TAuth;
    type AuthFactorType = TAuthFactorType;
    type AuthProviderConfig = TAuthProviderConfig;
    type AuthProviderConfigFilter = TAuthProviderConfigFilter;
    type BaseAuth = TBaseAuth;
    type CreateMultiFactorInfoRequest = TCreateMultiFactorInfoRequest;
    type CreatePhoneMultiFactorInfoRequest = TCreatePhoneMultiFactorInfoRequest;
    type CreateRequest = TCreateRequest;
    type CreateTenantRequest = TCreateTenantRequest;
    type DecodedIdToken = TDecodedIdToken;
    type DeleteUsersResult = TDeleteUsersResult;
    type EmailIdentifier = TEmailIdentifier;
    type EmailSignInProviderConfig = TEmailSignInProviderConfig;
    type GetUsersResult = TGetUsersResult;
    type HashAlgorithmType = THashAlgorithmType;
    type ListProviderConfigResults = TListProviderConfigResults;
    type ListTenantsResult = TListTenantsResult;
    type ListUsersResult = TListUsersResult;
    type MultiFactorCreateSettings = TMultiFactorCreateSettings;
    type MultiFactorConfig = TMultiFactorConfig;
    type MultiFactorConfigState = TMultiFactorConfigState;
    type MultiFactorInfo = TMultiFactorInfo;
    type MultiFactorUpdateSettings = TMultiFactorUpdateSettings;
    type MultiFactorSettings = TMultiFactorSettings;
    type OIDCAuthProviderConfig = TOIDCAuthProviderConfig;
    type OIDCUpdateAuthProviderRequest = TOIDCUpdateAuthProviderRequest;
    type PhoneIdentifier = TPhoneIdentifier;
    type PhoneMultiFactorInfo = TPhoneMultiFactorInfo;
    type ProviderIdentifier = TProviderIdentifier;
    type SAMLAuthProviderConfig = TSAMLAuthProviderConfig;
    type SAMLUpdateAuthProviderRequest = TSAMLUpdateAuthProviderRequest;
    type SessionCookieOptions = TSessionCookieOptions;
    type Tenant = TTenant;
    type TenantAwareAuth = TTenantAwareAuth;
    type TenantManager = TTenantManager;
    type UidIdentifier = TUidIdentifier;
    type UpdateAuthProviderRequest = TUpdateAuthProviderRequest;
    type UpdateMultiFactorInfoRequest = TUpdateMultiFactorInfoRequest;
    type UpdatePhoneMultiFactorInfoRequest = TUpdatePhoneMultiFactorInfoRequest;
    type UpdateRequest = TUpdateRequest;
    type UpdateTenantRequest = TUpdateTenantRequest;
    type UserIdentifier = TUserIdentifier;
    type UserImportOptions = TUserImportOptions;
    type UserImportRecord = TUserImportRecord;
    type UserImportResult = TUserImportResult;
    type UserInfo = TUserInfo;
    type UserMetadata = TUserMetadata;
    type UserMetadataRequest = TUserMetadataRequest;
    type UserProviderRequest = TUserProviderRequest;
    type UserRecord = TUserRecord;
}
