/*! firebase-admin v9.100.0-alpha.0 */
"use strict";
/*!
 * Copyright 2020 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.getInstanceId = exports.InstanceId = void 0;
var index_1 = require("../app/index");
var instance_id_1 = require("./instance-id");
Object.defineProperty(exports, "InstanceId", { enumerable: true, get: function () { return instance_id_1.InstanceId; } });
/**
 * Gets the {@link InstanceId `InstanceId`} service for the
 * default app or a given app.
 *
 * `getInstanceId()` can be called with no arguments to access the default
 * app's {@link InstanceId `InstanceId`} service or as
 * `getInstanceId(app)` to access the
 * {@link InstanceId `InstanceId`} service associated with a
 * specific app.
 *
 * @example
 * ```javascript
 * // Get the Instance ID service for the default app
 * const defaultInstanceId = getInstanceId();
 * ```
 *
 * @example
 * ```javascript
 * // Get the Instance ID service for a given app
 * const otherInstanceId = getInstanceId(otherApp);
 *```
 *
 * @param app Optional app whose `InstanceId` service to
 *   return. If not provided, the default `InstanceId` service will be
 *   returned.
 *
 * @return The default `InstanceId` service if
 *   no app is provided or the `InstanceId` service associated with the
 *   provided app.
 */
function getInstanceId(app) {
    if (typeof app === 'undefined') {
        app = index_1.getApp();
    }
    var firebaseApp = app;
    return firebaseApp.getOrInitService('instanceId', function (app) { return new instance_id_1.InstanceId(app); });
}
exports.getInstanceId = getInstanceId;
