/*! firebase-admin v9.100.0-alpha.0 */
/*!
 * Copyright 2018 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { App } from '../app';
import { ShaCertificate } from './android-app';
export declare function assertServerResponse(condition: boolean, responseData: object, message: string): void;
/**
 * Class that provides mechanism to send requests to the Firebase project management backend
 * endpoints.
 *
 * @private
 */
export declare class ProjectManagementRequestHandler {
    private readonly baseUrl;
    private readonly baseBetaUrl;
    private readonly httpClient;
    private static wrapAndRethrowHttpError;
    /**
     * @param app The app used to fetch access tokens to sign API requests.
     * @constructor
     */
    constructor(app: App);
    /**
     * @param {string} parentResourceName Fully-qualified resource name of the project whose Android
     *     apps you want to list.
     */
    listAndroidApps(parentResourceName: string): Promise<object>;
    /**
     * @param {string} parentResourceName Fully-qualified resource name of the project whose iOS apps
     *     you want to list.
     */
    listIosApps(parentResourceName: string): Promise<object>;
    /**
     * @param {string} parentResourceName Fully-qualified resource name of the project whose iOS apps
     *     you want to list.
     */
    listAppMetadata(parentResourceName: string): Promise<object>;
    /**
     * @param {string} parentResourceName Fully-qualified resource name of the project that you want
     *     to create the Android app within.
     */
    createAndroidApp(parentResourceName: string, packageName: string, displayName?: string): Promise<object>;
    /**
     * @param {string} parentResourceName Fully-qualified resource name of the project that you want
     *     to create the iOS app within.
     */
    createIosApp(parentResourceName: string, bundleId: string, displayName?: string): Promise<object>;
    /**
     * @param {string} resourceName Fully-qualified resource name of the entity whose display name you
     *     want to set.
     */
    setDisplayName(resourceName: string, newDisplayName: string): Promise<void>;
    /**
     * @param {string} parentResourceName Fully-qualified resource name of the Android app whose SHA
     *     certificates you want to get.
     */
    getAndroidShaCertificates(parentResourceName: string): Promise<object>;
    /**
     * @param {string} parentResourceName Fully-qualified resource name of the Android app that you
     *     want to add the given SHA certificate to.
     */
    addAndroidShaCertificate(parentResourceName: string, certificate: ShaCertificate): Promise<void>;
    /**
     * @param {string} parentResourceName Fully-qualified resource name of the app whose config you
     *     want to get.
     */
    getConfig(parentResourceName: string): Promise<object>;
    /**
     * @param {string} parentResourceName Fully-qualified resource name of the entity that you want to
     *     get.
     */
    getResource(parentResourceName: string): Promise<object>;
    /**
     * @param {string} resourceName Fully-qualified resource name of the entity that you want to
     *     delete.
     */
    deleteResource(resourceName: string): Promise<void>;
    private pollRemoteOperationWithExponentialBackoff;
    /**
     * Invokes the request handler with the provided request data.
     */
    private invokeRequestHandler;
}
